@@ -27,7 +27,7 @@
  * as follows.  Each message begins with a 1-character opcode which
  * specifies the message type.  The main library starts the plugins
  * by forking the helper process and establishes two pipes for
- * communication in both directions. 
+ * communication in both directions.
  * First, the main library send an 'INIT_STATE' message
  * to the plugin.  The start message specifies the name (and size)
  * of a shared memory segment which will contain parts of the (uncompressed)
@@ -39,7 +39,7 @@
  * size of the file (or -1 if unknown) and the number of bytes
  * ready in the shared memory segment.  The plugin then answers
  * with either:
- * 1) MESSAGE_DONE to indicate that no further processing is 
+ * 1) MESSAGE_DONE to indicate that no further processing is
  *    required for this file; the IPC continues with the
  *    EXTRACT_START message for the next file afterwards;
  * 2) MESSAGE_SEEK to indicate that the plugin would like to
@@ -92,7 +92,7 @@
 struct InitMessage
 {
   /**
-   * Set to MESSAGE_INIT_STATE.
+   * Set to #MESSAGE_INIT_STATE.
    */
   unsigned char opcode;
 
@@ -133,7 +133,7 @@ struct InitMessage
 struct StartMessage
 {
   /**
-   * Set to MESSAGE_EXTRACT_START.
+   * Set to #MESSAGE_EXTRACT_START.
    */
   unsigned char opcode;
 
@@ -161,7 +161,7 @@ struct StartMessage
 
 /**
  * Sent from LE to a plugin to tell it that shm contents
- * were updated. 
+ * were updated.
  */
 #define MESSAGE_UPDATED_SHM 0x02
 
@@ -171,7 +171,7 @@ struct StartMessage
 struct UpdateMessage
 {
   /**
-   * Set to MESSAGE_UPDATED_SHM.
+   * Set to #MESSAGE_UPDATED_SHM.
    */
   unsigned char opcode;
 
@@ -221,7 +221,7 @@ struct UpdateMessage
 struct SeekRequestMessage
 {
   /**
-   * Set to MESSAGE_SEEK.
+   * Set to #MESSAGE_SEEK.
    */
   unsigned char opcode;
 
@@ -245,7 +245,7 @@ struct SeekRequestMessage
   /**
    * Requested offset; a positive value from the end of the
    * file is used of 'whence' is SEEK_END; a postive value
-   * from the start is used of 'whence' is SEEK_SET.  
+   * from the start is used of 'whence' is SEEK_SET.
    * 'SEEK_CUR' is never used.
    */
   uint64_t file_offset;
@@ -263,7 +263,7 @@ struct SeekRequestMessage
 struct MetaMessage
 {
   /**
-   * Set to MESSAGE_META.
+   * Set to #MESSAGE_META.
    */
   unsigned char opcode;
 
@@ -292,9 +292,9 @@ struct MetaMessage
    */
   uint32_t value_size;
 
-  /* followed by mime_length bytes of 0-terminated 
+  /* followed by mime_length bytes of 0-terminated
      mime-type (unless mime_length is 0) */
-  
+
   /* followed by value_size bytes of value */
 
 };
@@ -355,7 +355,7 @@ EXTRACTOR_IPC_shared_memory_destroy_ (struct EXTRACTOR_SharedMemory *shm);
  */
 unsigned int
 EXTRACTOR_IPC_shared_memory_change_rc_ (struct EXTRACTOR_SharedMemory *shm,
-					int delta);
+                                        int delta);
 
 
 /**
@@ -369,9 +369,9 @@ EXTRACTOR_IPC_shared_memory_change_rc_ (struct EXTRACTOR_SharedMemory *shm,
  */
 ssize_t
 EXTRACTOR_IPC_shared_memory_set_ (struct EXTRACTOR_SharedMemory *shm,
-				  struct EXTRACTOR_Datasource *ds,
-				  uint64_t off,
-				  size_t size);
+                                  struct EXTRACTOR_Datasource *ds,
+                                  uint64_t off,
+                                  size_t size);
 
 
 /**
@@ -391,10 +391,10 @@ EXTRACTOR_datasource_get_pos_ (struct EXTRACTOR_Datasource *ds);
  * @param plugin the plugin
  * @param shm memory to share with the process
  * @return NULL on error, otherwise IPC channel
- */ 
+ */
 struct EXTRACTOR_Channel *
 EXTRACTOR_IPC_channel_create_ (struct EXTRACTOR_PluginList *plugin,
-			       struct EXTRACTOR_SharedMemory *shm);
+                               struct EXTRACTOR_SharedMemory *shm);
 
 
 /**
@@ -418,8 +418,8 @@ EXTRACTOR_IPC_channel_destroy_ (struct EXTRACTOR_Channel *channel);
  */
 ssize_t
 EXTRACTOR_IPC_channel_send_ (struct EXTRACTOR_Channel *channel,
-			     const void *data,
-			     size_t size);
+                             const void *data,
+                             size_t size);
 
 
 /**
@@ -434,12 +434,15 @@ EXTRACTOR_IPC_channel_send_ (struct EXTRACTOR_Channel *channel,
  * @param value_len number of bytes in 'value'
  */
 typedef void (*EXTRACTOR_ChannelMessageProcessor) (void *cls,
-						   struct EXTRACTOR_PluginList *plugin,
-						   enum EXTRACTOR_MetaType meta_type,
-						   enum EXTRACTOR_MetaFormat meta_format,
-						   const char *mime,
-						   const void *value,
-						   size_t value_len);
+                                                   struct EXTRACTOR_PluginList *
+                                                   plugin,
+                                                   enum EXTRACTOR_MetaType
+                                                   meta_type,
+                                                   enum EXTRACTOR_MetaFormat
+                                                   meta_format,
+                                                   const char *mime,
+                                                   const void *value,
+                                                   size_t value_len);
 
 
 /**
@@ -454,10 +457,10 @@ typedef void (*EXTRACTOR_ChannelMessageProcessor) (void *cls,
  */
 ssize_t
 EXTRACTOR_IPC_process_reply_ (struct EXTRACTOR_PluginList *plugin,
-			      const void *data,
-			      size_t size,
-			      EXTRACTOR_ChannelMessageProcessor proc,
-			      void *proc_cls);
+                              const void *data,
+                              size_t size,
+                              EXTRACTOR_ChannelMessageProcessor proc,
+                              void *proc_cls);
 
 
 /**
@@ -473,9 +476,9 @@ EXTRACTOR_IPC_process_reply_ (struct EXTRACTOR_PluginList *plugin,
  */
 int
 EXTRACTOR_IPC_channel_recv_ (struct EXTRACTOR_Channel **channels,
-			     unsigned int num_channels,
-			     EXTRACTOR_ChannelMessageProcessor proc,
-			     void *proc_cls);
+                             unsigned int num_channels,
+                             EXTRACTOR_ChannelMessageProcessor proc,
+                             void *proc_cls);
 
 
 #endif
