@@ -26,7 +26,6 @@
 #include "test_lib.h"
 
 
-
 /**
  * Main function for the FLAC testcase.
  *
@@ -37,39 +36,37 @@
 int
 main (int argc, char *argv[])
 {
-  struct SolutionData kraftwerk_sol[] =
+  struct SolutionData kraftwerk_sol[] = {
     {
-      { 
-	EXTRACTOR_METATYPE_RESOURCE_TYPE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"44100 Hz, 2 channels",
-	strlen ("44100 Hz, 2 channels") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_TITLE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"Test Title",
-	strlen ("Test Title") + 1,
-	0 
-      },
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct SolutionData alien_sol[] =
+      EXTRACTOR_METATYPE_RESOURCE_TYPE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "44100 Hz, 2 channels",
+      strlen ("44100 Hz, 2 channels") + 1,
+      0
+    },
     {
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct ProblemSet ps[] =
-    {
-      { "testdata/flac_kraftwerk.flac",
-	kraftwerk_sol },
-      { "testdata/mpeg_alien.mpg",
-	alien_sol },
-      { NULL, NULL }
-    };
+      EXTRACTOR_METATYPE_TITLE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "Test Title",
+      strlen ("Test Title") + 1,
+      0
+    },
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct SolutionData alien_sol[] = {
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct ProblemSet ps[] = {
+    { "testdata/flac_kraftwerk.flac",
+      kraftwerk_sol },
+    { "testdata/mpeg_alien.mpg",
+      alien_sol },
+    { NULL, NULL }
+  };
   return ET_main ("flac", ps);
 }
 
+
 /* end of test_flac.c */
