@@ -36,41 +36,40 @@
 int
 main (int argc, char *argv[])
 {
-  struct SolutionData it_dawn_sol[] =
+  struct SolutionData it_dawn_sol[] = {
     {
-      { 
-	EXTRACTOR_METATYPE_MIMETYPE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"audio/x-mod",
-	strlen ("audio/x-mod") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_TITLE,
-	EXTRACTOR_METAFORMAT_C_STRING,
-	"text/plain",
-	"Dawn",
-	strlen ("Dawn") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_FORMAT_VERSION,
-	EXTRACTOR_METAFORMAT_C_STRING,
-	"text/plain",
-	"1.2",
-	strlen ("1.2") + 1,
-	0 
-      },
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct ProblemSet ps[] =
+      EXTRACTOR_METATYPE_MIMETYPE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "audio/x-mod",
+      strlen ("audio/x-mod") + 1,
+      0
+    },
     {
-      { "testdata/it_dawn.it",
-	it_dawn_sol },
-      { NULL, NULL }
-    };
+      EXTRACTOR_METATYPE_TITLE,
+      EXTRACTOR_METAFORMAT_C_STRING,
+      "text/plain",
+      "Dawn",
+      strlen ("Dawn") + 1,
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_FORMAT_VERSION,
+      EXTRACTOR_METAFORMAT_C_STRING,
+      "text/plain",
+      "1.2",
+      strlen ("1.2") + 1,
+      0
+    },
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct ProblemSet ps[] = {
+    { "testdata/it_dawn.it",
+      it_dawn_sol },
+    { NULL, NULL }
+  };
   return ET_main ("it", ps);
 }
 
+
 /* end of test_it.c */
