@@ -27,6 +27,8 @@
 #include <sys/types.h>
 #include <regex.h>
 #include <signal.h>
+#include <stdbool.h>
+#include <unistd.h>
 
 /**
  * Function that libextractor calls for each
@@ -143,17 +145,31 @@ run (const char *plugin_name,
   unsigned int i;
   unsigned int j;
   int ret;
+  bool skipped = false;
 
   pl = EXTRACTOR_plugin_add_config (NULL,
                                     plugin_name,
                                     opt);
   for (i = 0; NULL != ps[i].filename; i++)
+  {
+    if (0 != access (ps[i].filename,
+                     R_OK))
+    {
+      fprintf (stderr,
+               "Failed to access %s, skipping test\n",
+               ps[i].filename);
+      skipped = true;
+      continue;
+    }
     EXTRACTOR_extract (pl,
                        ps[i].filename,
                        NULL, 0,
                        &process_replies,
                        ps[i].solution);
+  }
   EXTRACTOR_plugin_remove_all (pl);
+  if (skipped)
+    return 0;
   ret = 0;
   for (i = 0; NULL != ps[i].filename; i++)
     for (j = 0; -1 != ps[i].solution[j].solved; j++)
