@@ -36,57 +36,56 @@
 int
 main (int argc, char *argv[])
 {
-  struct SolutionData midi_dth_sol[] =
+  struct SolutionData midi_dth_sol[] = {
     {
-      { 
-	EXTRACTOR_METATYPE_MIMETYPE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"audio/midi",
-	strlen ("audio/midi") + 1,
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_COPYRIGHT,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"(c) 2012 d-o-o",
-	strlen ("(c) 2012 d-o-o"),
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_TITLE,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"Tage wie diese T2",
-	strlen ("Tage wie diese T2"),
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_COMMENT,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"XFhd:::Rock:8 Beat:1:m1:-:-:-:-:DD",
-	strlen ("XFhd:::Rock:8 Beat:1:m1:-:-:-:-:DD"),
-	0 
-      },
-      { 
-	EXTRACTOR_METATYPE_COMMENT,
-	EXTRACTOR_METAFORMAT_UTF8,
-	"text/plain",
-	"XFln:L1:Tage wie diese:von Holst:von Holst:-:Toten Hosen:DD",
-	strlen ("XFln:L1:Tage wie diese:von Holst:von Holst:-:Toten Hosen:DD"),
-	0 
-      },
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct ProblemSet ps[] =
+      EXTRACTOR_METATYPE_MIMETYPE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "audio/midi",
+      strlen ("audio/midi") + 1,
+      0
+    },
     {
-      { "testdata/midi_dth.mid",
-	midi_dth_sol },
-      { NULL, NULL }
-    };
+      EXTRACTOR_METATYPE_COPYRIGHT,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "(c) 2012 d-o-o",
+      strlen ("(c) 2012 d-o-o"),
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_TITLE,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "Tage wie diese T2",
+      strlen ("Tage wie diese T2"),
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_COMMENT,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "XFhd:::Rock:8 Beat:1:m1:-:-:-:-:DD",
+      strlen ("XFhd:::Rock:8 Beat:1:m1:-:-:-:-:DD"),
+      0
+    },
+    {
+      EXTRACTOR_METATYPE_COMMENT,
+      EXTRACTOR_METAFORMAT_UTF8,
+      "text/plain",
+      "XFln:L1:Tage wie diese:von Holst:von Holst:-:Toten Hosen:DD",
+      strlen ("XFln:L1:Tage wie diese:von Holst:von Holst:-:Toten Hosen:DD"),
+      0
+    },
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct ProblemSet ps[] = {
+    { "testdata/midi_dth.mid",
+      midi_dth_sol },
+    { NULL, NULL }
+  };
   return ET_main ("midi", ps);
 }
 
+
 /* end of test_midi.c */
